@@ -6,8 +6,7 @@ import root_path
 from transparentpath import Path
 import os
 import dotenv
-
-from adlinear import fed_nmtf
+from adlinear import nmfmodel as nmf
 
 dotenv.load_dotenv()
 
@@ -34,29 +33,40 @@ if __name__ == "__main__":
         df_epithor.drop(columns=df_epithor.columns[0:4], inplace=True)
         df_epithor.drop(labels=['Code', 'Suivi', 'Annee'], axis='columns', inplace=True)
         df_dense, _ = utl.drop_sparse_columns(df_epithor, minimum_fill_rate=0.8)
-        df_epi_normalized, df_epi_means, df_epistdevs = utl.normalize_by_columns(df_dense)
+        df_epi_normalized, df_epi_means, df_epistdevs = utl.normalize_by_columns(df_dense, make_positive=True)
         df_n_lines = len(df_dense.index)
         epithor_nb_feat = len(df_dense.columns)
         epithor_ncomp = 10
 
         # initialisation
+        global_model = nmf.NmfModel(df_epi_normalized, epithor_ncomp)
+        global_h: pd.DataFrame = global_model.get_h()
+        print(f"Erreur globale de la factorisation a {epithor_ncomp} composants: {global_model.get_precision()}")
         # centralizer
         centralizer: fd.NMFCentralizer = fd.NMFCentralizer(nfeat=epithor_nb_feat)
         centralizer.set_ncomp(ncomp=epithor_ncomp)
         # clients
-        nb_clients: int = 5
+        nb_clients: int = int(os.getenv("fed_nb_clients", 5))
         df_slice: int = int(df_n_lines / nb_clients)
         # création des clients
-        clients = [fd.NMFClient() for _ in range(nb_clients)]
+        clients = [fd.NMFClient(name="") for _ in range(nb_clients)]
+        clt_names = []
         # attribution des données aux clients
         for icl, client in enumerate(clients):
             client.set_data(df_epi_normalized.iloc[int(icl * df_slice): int((icl+1) * df_slice), :])
         # config
         fed_config: fd.FederatedNMFConfig = fd.FederatedNMFConfig(nmfcentral=centralizer,
                                                                   clients=clients)
+        fed_config.set_client_names([])
 
         fed_config.set_ncomp(epithor_ncomp)
         fed_config.set_features(df_epi_normalized.columns)
-        fed_config.request_update_step(client_idx=0)
-        fed_config.request_full_round()
+        # for _ in range(10):
+        #     fed_config.request_full_round()
+
+        fed_config.reset_counters()
+        fed_config.get_central().set_h_guess(global_h)
+        for _ in range(10):
+            fed_config.request_full_round()
+
         pass
\ No newline at end of file
